//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[DefaultYakuSerializer](index.md)

# DefaultYakuSerializer

[common]\
object [DefaultYakuSerializer](index.md) : KSerializer&lt;[Yaku](../-yaku/index.md)&gt;

## Properties

| Name | Summary |
|---|---|
| [descriptor](index.md#-1607891418%2FProperties%2F1581026887) | [common]<br>open override val [descriptor](index.md#-1607891418%2FProperties%2F1581026887): SerialDescriptor |

## Functions

| Name | Summary |
|---|---|
| [deserialize](index.md#1776074307%2FFunctions%2F1581026887) | [common]<br>open override fun [deserialize](index.md#1776074307%2FFunctions%2F1581026887)(decoder: Decoder): [Yaku](../-yaku/index.md) |
| [serialize](index.md#751609431%2FFunctions%2F1581026887) | [common]<br>open override fun [serialize](index.md#751609431%2FFunctions%2F1581026887)(encoder: Encoder, value: [Yaku](../-yaku/index.md)) |
